cantilever
=============================

|pypi| |py_versions| |codecov| |docs| |tests| |style|

.. |pypi| image:: https://img.shields.io/pypi/v/cantilever.svg
    :target: https://pypi.python.org/pypi/cantilever
    :alt: Current PyPi Version

.. |py_versions| image:: https://img.shields.io/pypi/pyversions/cantilever.svg
    :target: https://pypi.python.org/pypi/cantilever
    :alt: Supported Python Versions

.. |codecov| image:: https://codecov.io/gh/delaunay/cantilever/branch/master/graph/badge.svg?token=40Cr8V87HI
   :target: https://codecov.io/gh/delaunay/cantilever

.. |docs| image:: https://readthedocs.org/projects/cantilever/badge/?version=latest
   :target:  https://cantilever.readthedocs.io/en/latest/?badge=latest

.. |tests| image:: https://github.com/delaunay/cantilever/actions/workflows/test.yml/badge.svg?branch=master
   :target: https://github.com/delaunay/cantilever/actions/workflows/test.yml

.. |style| image:: https://github.com/delaunay/cantilever/actions/workflows/style.yml/badge.svg?branch=master
   :target: https://github.com/delaunay/cantilever/actions/workflows/style.yml



.. code-block:: bash

   pip install cantilever

